@@ -444,8 +444,11 @@ void ConfigWindow::updateGUI(bool overrideSync)
         }
 
         ui->timingInfo_checkBox->setChecked(sc->outputTiming);
+        ui->outputObjective_checkBox->setChecked(sc->outputObjective);
     }
 
+    ui->outputObjective_checkBox->setEnabled(sc->solverDefinition.inputType != Solver::I_MZN || sc->supports("--output-objective"));
+
     ui->numSolutions_spinBox->setEnabled(ui->numSolutions_checkBox->isEnabled() && ui->numSolutions_checkBox->isChecked());
     ui->numOptimal_spinBox->setEnabled(ui->numOptimal_checkBox->isEnabled() && ui->numOptimal_checkBox->isChecked());
 
@@ -527,6 +530,7 @@ void ConfigWindow::updateSolverConfig(SolverConfiguration* sc)
         s->compilationStats = ui->compilationStats_checkBox->isChecked();
         s->solvingStats = ui->solvingStats_checkBox->isChecked();
         s->outputTiming = ui->timingInfo_checkBox->isChecked();
+        s->outputObjective = ui->outputObjective_checkBox->isChecked();
     }
 
     sc->optimizationLevel = ui->optimizationLevel_comboBox->currentIndex();
