@@ -107,15 +107,16 @@ QString OutputWidget::lastTraceLoc(const QString &newTraceLoc)
     return ltl;
 }
 
-void OutputWidget::setDarkMode(bool darkMode)
+void OutputWidget::setTheme(const Theme& theme, bool darkMode)
 {
-    _noticeCharFormat.setForeground(Themes::currentTheme.functionColor.get(darkMode));
-    _errorCharFormat.setForeground(Themes::currentTheme.errorColor.get(darkMode));
-    _errorCharFormat.setForeground(Themes::currentTheme.errorColor.get(darkMode));
+    _defaultCharFormat.setForeground(theme.textColor.get(darkMode));
+    _noticeCharFormat.setForeground(theme.functionColor.get(darkMode));
+    _errorCharFormat.setForeground(theme.errorColor.get(darkMode));
+    _errorCharFormat.setForeground(theme.errorColor.get(darkMode));
     _infoCharFormat.setForeground(Qt::gray);
-    _commentCharFormat.setForeground(Themes::currentTheme.commentColor.get(darkMode));
+    _commentCharFormat.setForeground(theme.commentColor.get(darkMode));
 
-    ui->textBrowser->viewport()->setStyleSheet(Themes::currentTheme.styleSheet(darkMode));
+    ui->textBrowser->viewport()->setStyleSheet(theme.styleSheet(darkMode));
 }
 
 void OutputWidget::scrollToBottom()
@@ -126,6 +127,8 @@ void OutputWidget::scrollToBottom()
 
 void OutputWidget::startExecution(const QString& label)
 {
+    _checkerOutput.clear();
+
     TextLayoutLock lock(this);
     auto c = ui->textBrowser->textCursor();
     c.movePosition(QTextCursor::End);
@@ -186,7 +189,15 @@ void OutputWidget::addSolution(const QVariantMap& output, const QStringList& ord
             if (section == "html" || section.endsWith("_html")) {
                 addHtmlToSection(section, it.second.toString());
             } else {
-                addTextToSection(section, "% " + it.second.toString(), _commentCharFormat);
+                auto lines = it.second.toString().split("\n");
+                if (lines.last().isEmpty()) {
+                    lines.pop_back();
+                }
+                bool first = true;
+                for (auto& line : lines) {
+                    addTextToSection(section, (first ? "% " : "\n% ") + line, _commentCharFormat);
+                    first = false;
+                }
             }
             if (!cursor.block().text().isEmpty()) {
                 cursor.insertBlock();
@@ -268,8 +279,6 @@ void OutputWidget::addSolution(const QVariantMap& output, const QStringList& ord
 
 void OutputWidget::addCheckerOutput(const QVariantMap& output, const QStringList& order)
 {
-    // Print when we get solution
-    _checkerOutput.clear();
     for (auto& it : order) {
         _checkerOutput.append({it, output[it]});
     }
