@@ -35,8 +35,9 @@ int ParamDialog::getModel(const QStringList& modelFiles) {
         QFileInfo fi(modelFiles[i]);
         QListWidgetItem* lwi = new QListWidgetItem(fi.fileName());
         selectedFiles->addItem(lwi);
-        if (previousModelFile==modelFiles[i])
-            lwi->setSelected(true);
+        if (previousModelFile==modelFiles[i]) {
+            selectedFiles->setCurrentItem(lwi);
+        }
     }
     if (selectedFiles->selectedItems().size()==0) {
         selectedFiles->item(0)->setSelected(true);
@@ -62,13 +63,13 @@ void ParamDialog::getParams(QStringList params, const QStringList& dataFiles, QS
 {
     setWindowTitle("Model parameters");
     QVector<QLineEdit*> le;
-    formLayout = new QFormLayout;
 
     QFormLayout* mainLayout = new QFormLayout;
 
     QTabWidget* tw = new QTabWidget(this);
 
     QWidget* manual = new QWidget;
+    auto* formLayout = new QFormLayout;
     manual->setLayout(formLayout);
     bool fillPrevious = previousParams == params;
     for (int i=0; i<params.size(); i++) {
@@ -89,15 +90,18 @@ void ParamDialog::getParams(QStringList params, const QStringList& dataFiles, QS
             QFileInfo fi(dataFiles[i]);
             QListWidgetItem* lwi = new QListWidgetItem(fi.fileName());
             selectedFiles->addItem(lwi);
-            if (previousDataFiles.contains(dataFiles[i])) {
+            if (previousDataFiles.contains(dataFiles[i]) || additionalDataFiles.contains(dataFiles[i])) {
                 lwi->setSelected(true);
                 selectedFiles->setCurrentItem(lwi);
                 selectedFiles->scrollToItem(lwi);
             }
         }
-        tw->addTab(selectedFiles, "Select data file");
-        if (!fillPrevious || !previousWasManual)
+        tw->addTab(selectedFiles, "");
+        if (!fillPrevious || !previousWasManual) {
             tw->setCurrentIndex(1);
+        }
+        // Set now to workaround Qt bug where first tab doesn't appear
+        tw->setTabText(1, "Select data file");
     }
     mainLayout->addRow(tw);
     ui->frame->setLayout(mainLayout);
