@@ -38,7 +38,8 @@ PreferencesDialog::PreferencesDialog(bool addNewSolver, QWidget *parent) :
         } else {
             qDebug() << "internal error: cannot open cheat sheet.";
         }
-        _ce = new CodeEditor(nullptr, ":/cheat_sheet.mzn", false, false, editorFont, 2, false, _origDarkMode, nullptr, this);
+        auto& origTheme = IDE::instance()->themeManager->get(_origThemeIndex);
+        _ce = new CodeEditor(nullptr, ":/cheat_sheet.mzn", false, false, editorFont, 2, false, origTheme, _origDarkMode, nullptr, this);
         _ce->document()->setPlainText(fileContents);
         _ce->setReadOnly(true);
         ui->preview_verticalLayout->addWidget(_ce);
@@ -70,6 +71,9 @@ PreferencesDialog::PreferencesDialog(bool addNewSolver, QWidget *parent) :
         ui->compressSolutions_checkBox->setChecked(false);
     }
     ui->reuseVis_checkBox->setChecked(settings.value("reuseVis", false).toBool());
+    ui->visPort_spinBox->setValue(settings.value("visPort", 3000).toInt());
+    ui->visWsPort_spinBox->setValue(settings.value("visWsPort", 3100).toInt());
+    ui->visUrl_checkBox->setChecked(settings.value("printVisUrl", false).toBool());
     ui->printCommand_checkBox->setChecked(settings.value("printCommand", false).toBool());
     ui->indentSize_spinBox->setValue(settings.value("indentSize", 2).toInt());
     bool indentTabs = settings.value("indentTabs", false).toBool();
@@ -84,7 +88,8 @@ PreferencesDialog::PreferencesDialog(bool addNewSolver, QWidget *parent) :
         _origDarkMode = d->darkMode();
         ui->darkMode_checkBox->hide();
     }
-    _ce->setDarkMode(_origDarkMode);
+    auto* t = IDE::instance()->themeManager;
+    _ce->setTheme(t->get(_origThemeIndex), _origDarkMode);
     ui->darkMode_checkBox->setChecked(_origDarkMode);
     settings.endGroup();
     // Load user solver search paths
@@ -168,24 +173,10 @@ void PreferencesDialog::updateCodeEditorFont()
 
 void PreferencesDialog::on_theme_comboBox_currentIndexChanged(int index)
 {
-    switch (index) {
-    case 1:
-        Themes::currentTheme = Themes::blueberry;
-        break;
-    case 2:
-        Themes::currentTheme = Themes::mango;
-        break;
-    default:
-        Themes::currentTheme = Themes::minizinc;
-    }
-
-    auto* mw = qobject_cast<MainWindow*>(parentWidget());
-    if (mw != nullptr) {
-        // Refresh style
-        mw->setDarkMode(mw->isDarkMode());
-    }
-
-    _ce->setDarkMode(ui->darkMode_checkBox->isChecked());
+    auto* t = IDE::instance()->themeManager;
+    t->current(index);
+    IDE::instance()->refreshTheme();
+    _ce->setTheme(t->current(), ui->darkMode_checkBox->isChecked());
 }
 
 QByteArray PreferencesDialog::allowFileRestore(const QString& path)
@@ -444,7 +435,8 @@ bool PreferencesDialog::updateSolver()
         solvers[index]->id = ui->solverId->text().trimmed();
         solvers[index]->version = ui->version->text().trimmed();
         solvers[index]->isGUIApplication= ui->detach->isChecked();
-        solvers[index]->supportsMzn = !ui->needs_mzn2fzn->isChecked();
+        Solver::SolverInputType inputTypeMap[4] = { Solver::I_FZN, Solver::I_JSON, Solver::I_MZN, Solver::I_NL };
+        solvers[index]->inputType = inputTypeMap[ui->inputType_comboBox->currentIndex()];
         solvers[index]->needsSolns2Out = ui->needs_solns2out->isChecked();
 
         solvers[index]->stdFlags.removeAll("-a");
@@ -488,7 +480,11 @@ bool PreferencesDialog::updateSolver()
         json["id"] = ui->solverId->text().trimmed();
         json["version"] = ui->version->text().trimmed();
         json["isGUIApplication"] = ui->detach->isChecked();
-        json["supportsMzn"] = !ui->needs_mzn2fzn->isChecked();
+        QStringList inputTypeStringMap = { "FZN", "JSON", "MZN", "NL" };
+        json["inputType"] = inputTypeStringMap[ui->inputType_comboBox->currentIndex()];
+        json.remove("supportsFzn");
+        json.remove("supportsMzn");
+        json.remove("supportsNL");
         json["needsSolns2Out"] = ui->needs_solns2out->isChecked();
         json["stdFlags"] = QJsonArray::fromStringList(solvers[index]->stdFlags);
         QJsonDocument jdoc(json);
@@ -694,6 +690,11 @@ void PreferencesDialog::updateSearchPaths()
     } else if (obj.contains("mzn_solver_path")) {
         obj.remove("mzn_solver_path");
     }
+
+    QFileInfo uc_info(userConfigFile);
+    if (!QDir().mkpath(uc_info.absoluteDir().absolutePath())) {
+        showMessageBox("Cannot create user configuration directory "+uc_info.absoluteDir().absolutePath());
+    }
     if (uc.open(QFile::ReadWrite | QIODevice::Truncate)) {
         uc.write(QJsonDocument(obj).toJson());
         uc.close();
@@ -729,7 +730,23 @@ void PreferencesDialog::on_solvers_combo_currentIndexChanged(int index)
         ui->executable->setText(solvers[index]->executable);
         ui->exeNotFoundLabel->setVisible(!solvers[index]->executable.isEmpty() && solvers[index]->executable_resolved.isEmpty());
         ui->detach->setChecked(solvers[index]->isGUIApplication);
-        ui->needs_mzn2fzn->setChecked(!solvers[index]->supportsMzn);
+        switch (solvers[index]->inputType) {
+        case Solver::I_FZN:
+            ui->inputType_comboBox->setCurrentIndex(0);
+            break;
+        case Solver::I_JSON:
+            ui->inputType_comboBox->setCurrentIndex(1);
+            break;
+        case Solver::I_MZN:
+            ui->inputType_comboBox->setCurrentIndex(2);
+            break;
+        case Solver::I_NL:
+            ui->inputType_comboBox->setCurrentIndex(3);
+            break;
+        default:
+            ui->inputType_comboBox->setCurrentIndex(0);
+            break;
+        }
         ui->needs_solns2out->setChecked(solvers[index]->needsSolns2Out);
         ui->mznpath->setText(solvers[index]->mznlib);
         bool solverConfigIsUserEditable = false;
@@ -789,7 +806,7 @@ void PreferencesDialog::on_solvers_combo_currentIndexChanged(int index)
         ui->version->setText("");
         ui->executable->setText("");
         ui->detach->setChecked(false);
-        ui->needs_mzn2fzn->setChecked(true);
+        ui->inputType_comboBox->setCurrentIndex(0);
         ui->needs_solns2out->setChecked(true);
         ui->mznpath->setText("");
         ui->solverFrame->setEnabled(true);
@@ -902,6 +919,9 @@ void PreferencesDialog::on_PreferencesDialog_accepted()
                       ? ui->compressSolutions_spinBox->value() : 0);
     settings.setValue("printCommand", ui->printCommand_checkBox->isChecked());
     settings.setValue("reuseVis", ui->reuseVis_checkBox->isChecked());
+    settings.setValue("visPort", ui->visPort_spinBox->value());
+    settings.setValue("visWsPort", ui->visWsPort_spinBox->value());
+    settings.setValue("printVisUrl", ui->visUrl_checkBox->isChecked());
     settings.setValue("theme", ui->theme_comboBox->currentIndex());
     settings.setValue("indentTabs", ui->indentTabs_radioButton->isChecked());
     settings.setValue("indentSize", ui->indentSize_spinBox->value());
@@ -934,9 +954,10 @@ void PreferencesDialog::updateSolverLabel()
 void PreferencesDialog::on_darkMode_checkBox_stateChanged(int checked)
 {
     auto* d = IDE::instance()->darkModeNotifier;
+    auto* t = IDE::instance()->themeManager;
     bool dark = checked == Qt::Checked;
     d->requestChangeDarkMode(dark);
-    _ce->setDarkMode(d->darkMode());
+    _ce->setTheme(t->current(), d->darkMode());
 }
 
 void PreferencesDialog::on_zoom_spinBox_valueChanged(int value)
