@@ -193,7 +193,7 @@ void MznDriver::setLocation(const QString &mznDistribPath)
         throw DriverError(message);
     }
 
-    auto minVersion = QVersionNumber(2, 6, 0);
+    auto minVersion = QVersionNumber(2, 8, 0);
     if (_version < minVersion) {
         clear();
         throw DriverError("Versions of MiniZinc before " + minVersion.toString() + " are not supported.");
@@ -391,11 +391,14 @@ MznProcess::RunResult MznProcess::run(const QStringList& args, const QString& cw
     }
     p.start(exec[0], execArgs, MznDriver::get().mznDistribPath());
     if (!p.waitForStarted()) {
-        throw ProcessError("Failed to find or start minizinc " + args.join(" ") + ".");
+        throw ProcessError(QString("Failed to find or start %1 %2 in '%3'.")
+                               .arg(exec[0])
+                               .arg(args.join(" "))
+                               .arg(MznDriver::get().mznDistribPath())
+                           );
     }
     if (!p.waitForFinished()) {
         p.terminate();
-        throw ProcessError("Failed to run minizinc " + args.join(" ") + ".");
     }
     return { p.exitCode(), p.readAllStandardOutput(), p.readAllStandardError() };
 }
@@ -557,17 +560,42 @@ void MznProcess::onStdOutLine(const QString& line)
             qint64 time = msg["time"].isDouble() ? static_cast<qint64>(msg["time"].toDouble()) : -1;
             emit solutionOutput(sections, order, time);
         } else if (msg_type == "checker") {
-            auto sections = msg["output"].toObject().toVariantMap();
-            QStringList order;
-            if (msg["sections"].isArray()) {
-                for (auto it : msg["sections"].toArray()) {
-                    order << it.toString();
+            auto checkerSol = [&] (QJsonObject& msg) {
+                auto sections = msg["output"].toObject().toVariantMap();
+                QStringList order;
+                if (msg["sections"].isArray()) {
+                    for (auto it : msg["sections"].toArray()) {
+                        order << it.toString();
+                    }
+                } else {
+                    order = sections.keys();
+                }
+                qint64 time = msg["time"].isDouble() ? static_cast<qint64>(msg["time"].toDouble()) : -1;
+                emit checkerOutput(sections, order, time);
+            };
+
+            if (msg["messages"].isArray()) {
+                for (auto it : msg["messages"].toArray()) {
+                    auto msg = it.toObject();
+                    auto msg_type = msg["type"].toString();
+                    if (msg_type == "solution") {
+                        checkerSol(msg);
+                    } else if (msg_type == "trace") {
+                        auto section = msg["section"].toString();
+                        qint64 time = msg["time"].isDouble() ? static_cast<qint64>(msg["time"].toDouble()) : -1;
+                        emit checkerOutput({{section, msg["message"].toString()}}, {section}, time);
+                    } else if (msg_type == "comment") {
+                        auto comment = msg["comment"].toString();
+                        emit commentOutput(comment);
+                    } else if (msg_type == "warning") {
+                        emit warningOutput(msg);
+                    } else if (msg_type == "error") {
+                        emit errorOutput(msg);
+                    }
                 }
             } else {
-                order = sections.keys();
+                checkerSol(msg);
             }
-            qint64 time = msg["time"].isDouble() ? static_cast<qint64>(msg["time"].toDouble()) : -1;
-            emit checkerOutput(sections, order, time);
         } else if (msg_type == "status") {
             qint64 time = msg["time"].isDouble() ? static_cast<qint64>(msg["time"].toDouble()) : -1;
             emit finalStatus(msg["status"].toString(), time);
